==> haskell-language-c-0.4.7-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-language-c/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.4.7
id: language-c-0.4.7-c6d47132f778d5429ceb4abe6097e623
key: langu_IIvFSwa7ayRGnnggE8DLBX
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://www.sivity.net/projects/language.c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules:
    Language.C Language.C.Data Language.C.Data.Position
    Language.C.Data.Ident Language.C.Data.Error Language.C.Data.Name
    Language.C.Data.Node Language.C.Data.InputStream Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.Parser
    Language.C.Pretty Language.C.System.Preprocess
    Language.C.System.GCC Language.C.Analysis
    Language.C.Analysis.ConstEval Language.C.Analysis.Builtins
    Language.C.Analysis.SemError Language.C.Analysis.SemRep
    Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
    Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.Debug Language.C.Analysis.TypeCheck
    Language.C.Analysis.TypeConversions Language.C.Analysis.TypeUtils
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.Export
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/language-c-0.4.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/language-c-0.4.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/language-c-0.4.7
hs-libraries: HSlanguage-c-0.4.7-IIvFSwa7ayRGnnggE8DLBX
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-language-c/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.5.0
id: language-c-0.5.0-97eea64f505ccc31410026cfe9c15945
key: langu_JIXrZkWYa5pAYKPW9mqttD
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules:
    Language.C Language.C.Data Language.C.Data.Position
    Language.C.Data.Ident Language.C.Data.Error Language.C.Data.Name
    Language.C.Data.Node Language.C.Data.InputStream Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.Parser
    Language.C.Pretty Language.C.System.Preprocess
    Language.C.System.GCC Language.C.Analysis
    Language.C.Analysis.ConstEval Language.C.Analysis.Builtins
    Language.C.Analysis.SemError Language.C.Analysis.SemRep
    Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
    Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.Debug Language.C.Analysis.TypeCheck
    Language.C.Analysis.TypeConversions Language.C.Analysis.TypeUtils
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.Export
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/language-c-0.5.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/language-c-0.5.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/language-c-0.5.0
hs-libraries: HSlanguage-c-0.5.0-JIXrZkWYa5pAYKPW9mqttD
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
